import React, { useState, useRef, useEffect, useCallback } from 'react';
import { useQuery } from '@tanstack/react-query';
import { Link } from 'wouter';
import { apiRequest } from '../lib/queryClient';
import { CustomImage } from '../components/ui/custom-image';
import RecordingButton from '../components/recording-button/recording-button';
import MovieCard from '../components/movie-card';
import ActorSuggestions from '../components/actor-suggestions';
import { MediaSelectionModal } from '../components/media-selection-modal';
import { MovieCardSkeleton, HorizontalMovieCardSkeleton } from '../components/ui/movie-card-skeleton';
import { Skeleton } from '../components/ui/skeleton';
import TrailersSection from '../components/trailers-section';
import { FeaturesSection } from '../components/features-section';
import { PricingSection } from '../components/pricing-section';
import { IdentificationResult, TMDBMovie, TMDBTvShow } from '../types';
import debounce from 'lodash.debounce';
// Use type-only imports from shared schema
import type { Movie, TvShow, Actor, WatchHistory } from '../../../shared/schema';
import { useToast } from '../hooks/use-toast';
import { useLocation } from 'wouter';
import { SearchMode } from '../hooks/use-movie-identification';
import { autocorrectQuery, correctSpellingErrors } from '../utils/autocorrect';
import { useSpellChecker } from '../hooks/use-spell-checker';
import { useAuth } from '../contexts/auth-context';
import { filterSearchResults, isLikelyActorSearch } from '../utils/search-utils';

// Define interfaces for the media details data
interface MediaDetails {
  id: number;
  tmdbId?: number;
  posterPath?: string;
  poster_path_full?: string;  // Added for full URL paths from backend
  title?: string;
  name?: string;
  overview?: string;
  backdropPath?: string;
  backdrop_path_full?: string;  // Added for full URL paths from backend
  releaseDate?: string;
  firstAirDate?: string;
  genres?: string[];
  voteAverage?: number;
}

// WatchHistoryItem component to properly handle React hooks
interface WatchHistoryItemProps {
  item: WatchHistory & { tmdbId?: number | null };
  mediaId: number;
  navigateWithHistory: (path: string) => void;
}

function WatchHistoryItem({ item, mediaId, navigateWithHistory }: WatchHistoryItemProps) {
  // Use the query hook here according to React rules
  // For TV shows with seasons, fetch season-specific data, otherwise fetch general media data
  const apiEndpoint = item.mediaType === 'tv' && item.seasonNumber 
    ? `/api/${item.mediaType}/${mediaId}/season/${item.seasonNumber}`
    : `/api/${item.mediaType}/${mediaId}`;

  const { data: mediaDetails } = useQuery<MediaDetails>({
    queryKey: [apiEndpoint],
    enabled: !!mediaId,
  });

  // Helper function to get the poster path consistently
  const getPosterUrl = (details: MediaDetails) => {
    // First try the full path if available (from poster_path_full)
    if (details.poster_path_full) {
      return details.poster_path_full;
    }

    // Next check if posterPath exists and handle both formats
    if (details.posterPath) {
      return details.posterPath.startsWith('http') 
        ? details.posterPath 
        : details.posterPath;
    }

    // Finally fallback to placeholder
    return 'https://placehold.co/342x500/141414/1f1f1f.png?text=No+Image';
  };



  return (
    <div className="flex-none">
      <div className="cursor-pointer" onClick={() => {
        // Use our navigation wrapper to maintain history state properly
        navigateWithHistory(`/${item.mediaType}/${mediaId}`);
      }}>
        <div className="w-32 md:w-44 rounded-md overflow-hidden">
          {mediaDetails ? (
            <div className="relative">
              <div className="aspect-[2/3] relative overflow-hidden">
                <CustomImage
                  src={getPosterUrl(mediaDetails)}
                  alt={mediaDetails.title || mediaDetails.name || `${item.mediaType} #${mediaId}`}
                  className="w-full h-full"
                  enableSkeleton={true}
                  fallbackSrc="https://placehold.co/300x450/141414/1f1f1f?text=No+Image"
                />
              </div>
              <div className="p-2 bg-[#262626] rounded-b-md">
                <h5 className="text-sm font-medium text-white truncate">
                  {mediaDetails.title || mediaDetails.name}
                  {item.mediaType === 'tv' && item.seasonNumber && (
                    <span className="text-xs text-gray-300 block">
                      {item.seasonName || `Season ${item.seasonNumber}`}
                    </span>
                  )}
                </h5>
                <p className="text-xs text-gray-400">
                  {new Date(item.watchedAt).toLocaleDateString()}
                </p>
              </div>
            </div>
          ) : (
            <>
              <div className="h-44 md:h-64 w-32 md:w-44 flex items-center justify-center bg-[#1f1f1f]">
                <p className="text-center p-4 text-sm text-gray-400">
                  {item.mediaType === 'movie' ? 'Movie' : 'TV Show'} #{mediaId}
                </p>
              </div>
              <div className="p-2 bg-[#262626] rounded-b-md">
                <h5 className="text-sm font-medium text-white truncate">
                  {item.mediaType === 'movie' ? 'Movie' : 'TV Show'} #{mediaId}
                </h5>
                <p className="text-xs text-gray-400">
                  {new Date(item.watchedAt).toLocaleDateString()}
                </p>
              </div>
            </>
          )}
        </div>
      </div>
    </div>
  );
}


export default function Home() {

  const [searchQuery, setSearchQuery] = useState(''); 
  const [location, navigate] = useLocation();

  // Track if component is mounted (for cleanup)
  const isMounted = useRef(true);

  // Apply spell check immediately function
  const applySpellCheck = useCallback((value: string) => {
    if (!isMounted.current) return value; // Skip if component unmounted
    if (!value.trim()) return value;

    // Special handling for "warlord" or "war" terms - NEVER autocorrect these
    if (value.toLowerCase().includes("warlord") || 
        value.toLowerCase() === "war" ||
        value.toLowerCase().startsWith("war")) {
      console.log(`Preserving war-related term: "${value}" - skipping auto-correction`);
      return value; // Return the original value unchanged
    }

    const corrected = autocorrectQuery(value);
    if (corrected !== value) {
      console.log(`Autocorrected: "${value}" → "${corrected}"`);
      return corrected;
    }
    return value;
  }, []);

  // Set up cleanup for the component
  useEffect(() => {
    return () => {
      isMounted.current = false;
    };
  }, []);

  // Clear referrer paths when navigating to home page
  // This fixes issues with back button when moving between movie details
  useEffect(() => {
    sessionStorage.removeItem('movieDetailReferrer');
    sessionStorage.removeItem('tvDetailReferrer');
  }, []);

  // Wrapper for navigate to ensure consistent history behavior
  const navigateWithHistory = (path: string) => {
    console.log('Navigating to:', path);
    
    // Store referrer path in sessionStorage when navigating to detail pages
    if (path.startsWith('/movie/')) {
      sessionStorage.setItem('movieDetailReferrer', location);
    } else if (path.startsWith('/tv/')) {
      sessionStorage.setItem('tvDetailReferrer', location);
    }

    navigate(path);
  };
  const [showSelectionModal, setShowSelectionModal] = useState(false); // State for selection modal
  const [multipleResults, setMultipleResults] = useState<{ movies: TMDBMovie[]; tvShows: TMDBTvShow[]; } | null>(null); // State for multiple results
  const [searchMode, setSearchMode] = useState<SearchMode>('auto'); // Current search mode
  const { user } = useAuth(); // Add useAuth hook

  /**
   * Determine if the input looks like a person's name
   * This is a simplified version of the analysis done in useMovieIdentification
   */
  const isInputNameLike = (input: string): boolean => {
    if (!input || input.length < 2) return false;

    const words = input.trim().split(/\s+/);

    // Common media words that should never be in names
    const mediaWords = ['game', 'movie', 'show', 'series', 'season', 'episode', 'tv', 'film', 
                        'the', 'legend', 'revenge', 'return', 'rise', 'of', 'and', 'in'];

    // Check if it contains obvious media words
    const hasObviousMediaWord = words.some(w => mediaWords.includes(w.toLowerCase()));

    // Check for numbers (sequels, years) which strongly indicate media, not actor names
    const hasNumbers = /\d/.test(input);

    // Basic name pattern: 2-3 words, all alphabetic
    const looksLikeName = !hasObviousMediaWord && 
                          !hasNumbers &&
                          words.length >= 2 && 
                          words.length <= 3 &&
                          words.every(w => w.length > 1 && /^[A-Za-z]+$/.test(w));

    return looksLikeName;
  };

  // Fetch currently watching media
  const { data: watchHistory, isLoading: isLoadingHistory, refetch: refetchWatchHistory } = useQuery<(WatchHistory & { tmdbId?: number | null })[]>({
    queryKey: ['/api/user/watchhistory'],
    enabled: !!user, // Only run if user is logged in
    select: (data) => {
      // Enhanced array safety check to prevent React error #31
      if (!data || !Array.isArray(data)) {
        console.error('Home: watchHistory data is not an array:', typeof data, data);
        return [];
      }
      
      const watchingItems = data.filter(item => item.status === 'watching') || [];

      // Apply comprehensive deduplication logic
      const uniqueMediaByStatusMap = new Map();

      // Sort by newest first to prioritize the most recent entries
      const sortedItems = [...watchingItems].sort((a, b) => {
        const dateA = new Date(a.watchedAt).getTime();
        const dateB = new Date(b.watchedAt).getTime();
        return dateB - dateA; // Descending order (newest first)
      });

      // Group items by their unique media identifier including season for TV shows
      for (const item of sortedItems) {
        // Create a unique key for this media item, including season for TV shows
        const mediaKey = `${item.mediaType}-${item.tmdbId || item.mediaId}${item.mediaType === 'tv' && item.seasonNumber ? `-s${item.seasonNumber}` : ''}`;
        const statusKey = item.status; // Should be 'watching' here

        // Combine keys to ensure we have one entry per status per media item
        const uniqueKey = `${mediaKey}-${statusKey}`;

        // Only add if we haven't seen this unique key yet
        if (!uniqueMediaByStatusMap.has(uniqueKey)) {
          uniqueMediaByStatusMap.set(uniqueKey, item);
        }
      }

      // Convert the map to an array with unique entries
      return Array.from(uniqueMediaByStatusMap.values());
    }
  });

  // Listen for watchlist updates from navigation buttons to refresh homepage watching section
  useEffect(() => {
    const handleWatchlistUpdate = (event: CustomEvent) => {
      const { type, status, action } = event.detail;
      // Refresh watching section when items are removed from watching status
      // Handle both old format (type/status) and new format (action)
      if ((type === 'removed' && status === 'watching') || 
          (action === 'remove' && (status === 'watching' || !status))) {
        console.log('🏠 HOME - Refreshing watching section due to watchlist removal');
        refetchWatchHistory();
      }
    };

    window.addEventListener('watchlist-update', handleWatchlistUpdate as EventListener);
    return () => {
      window.removeEventListener('watchlist-update', handleWatchlistUpdate as EventListener);
    };
  }, [refetchWatchHistory]);

  // Fetch upcoming movies and shows
  const { data: upcomingData, isLoading: isLoadingUpcoming } = useQuery({
    queryKey: ['/api/coming-soon'],
    staleTime: 3600000,
    gcTime: 7200000,
    refetchOnMount: false,
    refetchOnWindowFocus: false,
    retry: 1
  });

  // Extract results array from API response
  const upcomingContent = upcomingData?.results || [];
  
  // Debug logging for upcoming movies
  React.useEffect(() => {
    if (upcomingData) {
      console.log('🎭 Upcoming movies data received:', {
        totalResults: upcomingData.total_results,
        resultsCount: upcomingContent.length,
        firstMovie: upcomingContent[0]
      });
    }
  }, [upcomingData, upcomingContent]);

  // Fetch popular movies for recommendations
  const { data: popularMoviesData, isLoading: isLoadingMovies } = useQuery({
    queryKey: ['/api/popular/movies'],
    staleTime: 3600000, 
    gcTime: 7200000, 
    refetchOnMount: false,
    refetchOnWindowFocus: false,
    retry: 1 
  });

  // Extract results array from API response
  const popularMovies = popularMoviesData?.results || [];
  
  // Debug logging for popular movies
  React.useEffect(() => {
    if (popularMoviesData) {
      console.log('🎬 Popular movies data received:', {
        totalResults: popularMoviesData.total_results,
        resultsCount: popularMovies.length,
        firstMovie: popularMovies[0]
      });
    }
  }, [popularMoviesData, popularMovies]);



  // Handle identification result - SIMPLIFIED DEVELOPMENT SITE PATTERN
  const handleIdentified = (result: IdentificationResult) => {
    console.log('HANDLE IDENTIFIED called with:', result);
    console.log('multipleResults:', result.multipleResults);
    console.log('movies:', result.movies);
    console.log('tvShows:', result.tvShows);

    // Always clear the search input when results are found
    setSearchQuery('');

    if (result.success) {
      if (result.multipleResults && result.movies && result.tvShows) {
        console.log('Multiple results found:', result.movies, result.tvShows);

        // Set multiple results and show modal
        setMultipleResults({
          movies: result.movies || [],
          tvShows: result.tvShows || []
        });
        console.log('Setting showSelectionModal to true');
        setShowSelectionModal(true);
        return;
      }

      if (result.media) {
        if (result.mediaType === 'actor') {
          const actorData = result.media as Actor;
          // Use tmdbId when available, otherwise fallback to id
          const actorId = actorData.tmdbId || actorData.id;

          if (actorId) {
            console.log(`Navigating to actor detail page:`, actorId);
            navigateWithHistory(`/actor/${actorId}`);
          } else {
            console.error('No valid ID found for actor:', actorData);
            toast({
              title: "Navigation Error",
              description: "Could not find a valid ID for this actor",
              variant: "destructive"
            });
          }
        } else {
          // Instead of showing modal, navigate directly to the detail page
          const media = result.media as Movie | TvShow;
          const mediaType = result.mediaType === 'movie' ? 'movie' : 'tv';
          const mediaId = media.id || (media.tmdbId ? media.tmdbId : 0);

          if (mediaId) {
            console.log(`Navigating to ${mediaType} detail page:`, mediaId);
            navigateWithHistory(`/${mediaType}/${mediaId}`);
          } else {
            console.error('No valid ID found for media:', media);
            toast({
              title: "Navigation Error",
              description: "Could not find a valid ID for this content",
              variant: "destructive"
            });
          }
        }
      } else {
        toast({
          title: "No Match Found",
          description: `Could not find a match for "${result.transcription || 'your recording'}"`,
          variant: "destructive"
        });
      }
    }
  };



  // Add state for search results
  const { toast } = useToast();

  const handleQuerySubmit = async (event: React.FormEvent) => {
    event.preventDefault();

    if (!searchQuery.trim()) {
      toast({
        title: "Empty search",
        description: "Please enter a search term",
        variant: "destructive"
      });
      return;
    }

    try {
      // Instead of duplicating logic, we'll trigger the RecordingButton component
      // which already has the proper search by text functionality
      const buttonElement = document.querySelector('.recording-button') as HTMLButtonElement;
      if (buttonElement) {
        buttonElement.click();
      } else {
        console.error("Recording button element not found");
        // Fallback in case button is not found
        toast({
          title: "Search error",
          description: "Could not trigger search. Please try again.",
          variant: "destructive"
        });
      }
    } catch (error) {
      console.error("Search error:", error);
      toast({
        title: "Search failed",
        description: "There was an error processing your search",
        variant: "destructive"
      });
    }
  };

  // Navigate to detail page for any media type
  const handleShowDetail = (media: any) => {
    // Use tmdbId if available, otherwise fallback to id
    const mediaId = media?.tmdbId || media?.id;

    if (!media || !mediaId) {
      console.error('Invalid media object or missing ID:', media);
      return;
    }

    // Check if it's an actor by looking for actor-specific properties
    if (media.name && !media.title && !media.first_air_date) {
      console.log('Navigating to actor page:', mediaId);
      navigateWithHistory(`/actor/${mediaId}`);
    } else if (media.title) {
      console.log('Navigating to movie page:', mediaId);
      navigateWithHistory(`/movie/${mediaId}`);
    } else {
      console.log('Navigating to TV show page:', mediaId);
      navigateWithHistory(`/tv/${mediaId}`);
    }
  };

  const [isSearching, setIsSearching] = useState(false);
  const [searchResults, setSearchResults] = useState<{
    movies: TMDBMovie[];
    tvShows: TMDBTvShow[];
  } | null>(null);
  const [movies, setMovies] = useState<TMDBMovie[]>([]);
  const [tvShows, setTvShows] = useState<TMDBTvShow[]>([]);


  return (
    <section className="pb-12 px-4 lg:px-10">
      {/* Upper section - within the gradient */}
      <div className="pt-20 mb-10 text-center">
        <h2 className="text-3xl md:text-4xl font-bold mb-2 text-[#d7301e]">Flick me and find out</h2>
        <p className="text-[#c0c0c0] mb-6 max-w-2xl mx-auto">
          Discover and track movies, shows and actors.
        </p>

        <div className="flex flex-col items-center gap-4 max-w-md mx-auto mt-10">
          {/* Recording button */}
          {!searchQuery.trim() ? (
            <RecordingButton 
              mode="auto"
              onIdentified={handleIdentified} 
              onShowDetail={(actor) => {
                // Clear the search input before navigating
                setSearchQuery('');
                handleShowDetail(actor);
              }} 
              onShowMovie={(media) => {
                console.log('onShowMovie called with media:', media);
                // Clear the search input before navigating
                setSearchQuery('');
                // Navigate to the appropriate detail page based on media type
                const mediaType = 'title' in media ? 'movie' : 'tv';
                const mediaId = media.id || (media.tmdbId ? media.tmdbId : 0);
                if (mediaId) {
                  navigateWithHistory(`/${mediaType}/${mediaId}`);
                }
              }}
            />
          ) : (
            <RecordingButton 
              mode="text"
              textQuery={searchQuery}
              onIdentified={handleIdentified} 
              onShowDetail={(actor) => {
                // Clear the search input before navigating
                setSearchQuery('');
                handleShowDetail(actor);
              }} 
              onShowMovie={(media) => {
                console.log('onShowMovie called with media:', media);
                // Clear the search input before navigating
                setSearchQuery('');
                // Navigate to the appropriate detail page based on media type
                const mediaType = 'title' in media ? 'movie' : 'tv';
                const mediaId = media.id || (media.tmdbId ? media.tmdbId : 0);
                if (mediaId) {
                  navigateWithHistory(`/${mediaType}/${mediaId}`);
                }
              }}
            />
          )}

          {/* Text search input */}
          <div className="w-1/2 mx-auto relative">
            {/* Simple direct input with no spell checking */}
            <input
              type="text"
              value={searchQuery}
              onChange={(e) => {
                // Directly set the value without any spell checking or processing
                setSearchQuery(e.target.value.trimStart());
              }}
              placeholder="Or type your search here..."
              className="w-full rounded-full bg-[#1f1f1f] px-3 py-2 text-sm text-white border-none focus-visible:outline-none"
              onKeyDown={(e) => {
                if (e.key === 'Enter' && searchQuery.trim()) {
                  e.preventDefault();
                  // Just trim and use the raw query exactly as typed
                  setSearchQuery(searchQuery.trim());
                  const buttonElement = document.querySelector('.recording-button') as HTMLButtonElement;
                  if (buttonElement) {
                    buttonElement.click();
                  }
                }
              }}
              // Completely disable all forms of spell checking and auto-correction
              spellCheck={false}
              autoCorrect="off"
              autoCapitalize="off"
              autoComplete="off"
            />

            {/* Actor suggestions - Only show for name-like queries */}
            {searchQuery.trim().length > 0 && (
              <ActorSuggestions 
                query={searchQuery} 
                visible={isInputNameLike(searchQuery)}
                onSelect={(actor) => {
                  // Clear the search input and navigate to actor page
                  setSearchQuery('');
                  const actorId = actor.id;
                  if (actorId) {
                    navigateWithHistory(`/actor/${actorId}`);
                  }
                }}
              />
            )}
          </div>
        </div>
        <p className="text-sm text-gray-400 max-w-md mx-auto mt-4"></p>
      </div>

      {/* Search Results */}
      {searchResults && (
        <div className="mb-12">
          <h3 className="text-xl font-bold mb-4">Search Results for "{searchQuery}"</h3>

          {/* Movies section */}
          {Array.isArray(searchResults.movies) && searchResults.movies.length > 0 && (
            <div className="mb-8">
              <h4 className="text-lg font-medium mb-3">Movies</h4>
              <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-5 gap-4">
                {searchResults.movies.map((movie) => (
                  <div 
                    key={movie.id}
                    className="cursor-pointer transition-transform hover:scale-105"
                    onClick={() => navigateWithHistory(`/movie/${movie.id}`)}
                  >
                    <CustomImage
                      src={movie.poster_path || undefined}
                      alt={movie.title}
                      className="rounded-sm w-full"
                      aspectRatio="aspect-[2/3]"
                      enableSkeleton={true}
                    />
                    <div className="mt-2">
                      <h5 className="text-sm font-medium text-white truncate">{movie.title}</h5>
                      <p className="text-xs text-gray-400">
                        {movie.release_date && `${movie.release_date.split('-')[0]}`}
                      </p>
                    </div>
                  </div>
                ))}
              </div>
            </div>
          )}

          {/* TV Shows section */}
          {Array.isArray(searchResults.tvShows) && searchResults.tvShows.length > 0 && (
            <div>
              <h4 className="text-lg font-medium mb-3">TV Shows</h4>
              <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-5 gap-4">
                {searchResults.tvShows.map((show) => (
                  <div 
                    key={show.id}
                    className="cursor-pointer transition-transform hover:scale-105"
                    onClick={() => navigateWithHistory(`/tv/${show.id}`)}
                  >
                    <img 
                      src={show.poster_path || 'https://placehold.co/400x600/141414/1f1f1f?text=No+Image'} 
                      alt={show.name} 
                      className="rounded-sm object-cover w-full aspect-[2/3]"
                      loading="lazy"
                    />
                    <div className="mt-2">
                      <h5 className="text-sm font-medium text-white truncate">{show.name}</h5>
                      <p className="text-xs text-gray-400">
                        {show.first_air_date && `${show.first_air_date.split('-')[0]}`}
                      </p>
                    </div>
                  </div>
                ))}
              </div>
            </div>
          )}

          {/* No results message */}
          {(!Array.isArray(searchResults.movies) || searchResults.movies.length === 0) && 
           (!Array.isArray(searchResults.tvShows) || searchResults.tvShows.length === 0) && (
            <p className="text-gray-400">No results found for "{searchQuery}"</p>
          )}
        </div>
      )}

      {/* Content sections begin here */}
      <div className="pt-8 mt-6">

        {/* Watching - Only show if there are items */}
        {(Array.isArray(watchHistory) && watchHistory.length > 0) && (
          <div className="mb-12">
            <h3 className="text-xl font-bold mb-4">Watching</h3>

            {!isLoadingHistory && Array.isArray(watchHistory) && watchHistory.length > 0 ? (
              <div className="flex overflow-x-auto scrollbar-hide space-x-4 pb-4">
                {watchHistory.map(item => {
                  // Use tmdbId when available, otherwise fall back to local mediaId
                  const mediaIdToUse = item.tmdbId !== undefined && item.tmdbId !== null 
                    ? Number(item.tmdbId) 
                    : item.mediaId;

                  return (
                    <WatchHistoryItem 
                      key={item.id} 
                      item={item} 
                      mediaId={mediaIdToUse}
                      navigateWithHistory={navigateWithHistory}
                    />
                  );
                })}
              </div>
            ) : !isLoadingHistory ? (
              <p className="text-gray-400">Nothing in your watching list yet. Start watching something to get started.</p>
            ) : null}
          </div>
        )}

        {/* Coming Soon */}
        <div className="mb-12">
          <h2 className="text-2xl font-bold mb-4">Coming Soon</h2>

          {!isLoadingUpcoming && upcomingContent && upcomingContent.length > 0 ? (
            <div className="flex overflow-x-auto scrollbar-hide space-x-4 pb-4">
              {upcomingContent
                // Filter out movies that are missing essential information
                .filter(item => {
                  // Skip movies without a poster or with placeholder/incomplete information
                  // Specifically target Avengers: Secret Wars and Tron: Ares if they don't have complete info
                  const missingPoster = !item.poster_path || item.poster_path.includes('placehold');
                  const isFutureMarvelMovie = (item.id === 836487 || item.id === 1235360); // Secret Wars or Tron: Ares

                  // Only include movies that either:
                  // 1. Have complete information (poster and not a future Marvel movie)
                  // 2. OR are future Marvel movies with complete information
                  return !missingPoster && (!isFutureMarvelMovie || (isFutureMarvelMovie && item.trailerKey));
                })
                .map(item => {
                // Determine if it's a movie or TV show
                const isMovie = item.media_type === 'movie';
                // Handle potential null release dates
                const releaseDate = item.release_date ? new Date(item.release_date) : new Date();
                const now = new Date();
                const isReleased = releaseDate <= now;

                return (
                  <Link 
                    key={`${item.media_type}-${item.id}`} 
                    href={`/${isMovie ? 'movie' : 'tv'}/${item.id}`} 
                    className="flex-none w-32 md:w-44"
                  >
                    <div className="overflow-hidden">
                      <div className="aspect-[2/3] relative overflow-hidden rounded-t-md">
                        <img 
                          src={item.poster_path || 'https://placehold.co/400x600/141414/1f1f1f?text=No+Image'} 
                          alt={item.title} 
                          className="w-full h-full object-cover"
                          loading="lazy"
                        />
                      </div>
                      <div className="p-2 bg-[#262626] rounded-b-md">
                        <h4 className="text-sm font-medium text-white truncate">{item.title}</h4>
                        <p className="text-xs text-gray-400">
                          {item.release_date && 
                            (isReleased ? 
                              `${isMovie ? 'Released' : 'Streaming'} ${releaseDate.toLocaleDateString()}` : 
                              `Coming ${releaseDate.toLocaleDateString()}`
                            )
                          }
                        </p>
                      </div>
                    </div>
                  </Link>
                );
              })}
            </div>
          ) : !isLoadingUpcoming ? (
            <p className="text-gray-400">No upcoming releases found.</p>
          ) : null}
        </div>

        {/* Hot Trailers Section - Dynamic trailers from trending data */}
        <div className="mb-12">
          <TrailersSection 
            useFreshTrailers={true} 
            maxTrailers={5}
            title={<>
              <span className="flex items-center">
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-6 h-6 text-orange-500 mr-2">
                  <path fillRule="evenodd" d="M12.963 2.286a.75.75 0 00-1.071-.136 9.742 9.742 0 00-3.539 6.177A7.547 7.547 0 016.648 6.61a.75.75 0 00-1.152.082A9 9 0 1015.68 4.534a7.46 7.46 0 01-2.717-2.248zM15.75 14.25a3.75 3.75 0 11-7.313-1.172c.628.465 1.35.81 2.133 1a5.99 5.99 0 011.925-3.545 3.75 3.75 0 013.255 3.717z" clipRule="evenodd" />
                </svg>
                Trailers
              </span>
            </>} 
            subtitle=""
          />
        </div>

        {/* Recommended for You */}
        <div className="mb-12">
          <h2 className="text-2xl font-bold mb-4">Recommended for You</h2>

          {!isLoadingMovies && Array.isArray(popularMovies) && popularMovies.length > 0 ? (
            <div className="flex overflow-x-auto scrollbar-hide space-x-4 pb-4">
              {popularMovies.map(movie => (
                <Link key={movie.id} href={`/movie/${movie.id}`} className="flex-none w-32 md:w-44">
                  <div className="overflow-hidden">
                    <div className="aspect-[2/3] relative overflow-hidden rounded-t-md">
                      <img 
                        src={movie.poster_path || 'https://placehold.co/400x600/141414/1f1f1f?text=No+Image'} 
                        alt={movie.title} 
                        className="w-full h-full object-cover"
                        loading="lazy"
                      />
                    </div>
                    <div className="p-2 bg-[#262626] rounded-b-md">
                      <h4 className="text-sm font-medium text-white truncate">{movie.title}</h4>
                      <p className="text-xs text-gray-400">
                        Movie {movie.release_date && `• ${movie.release_date.split('-')[0]}`}
                      </p>
                    </div>
                  </div>
                </Link>
              ))}
            </div>
          ) : !isLoadingMovies ? (
            <p className="text-gray-400">No recommendations available.</p>
          ) : null}
        </div>

        {/* Features and Pricing Sections */}
        <div className="mt-12">
          <FeaturesSection />
          <PricingSection />
        </div>
      </div>

      {/* Selection Modal for multiple results */}
      {(() => {
        // Debug for modal data at render time
        if (showSelectionModal && multipleResults) {
          console.log('🚨 RENDER: Showing selection modal with data:', {
            movies: multipleResults.movies,
            moviesCount: multipleResults.movies?.length || 0,
            tvShows: multipleResults.tvShows,
            tvShowsCount: multipleResults.tvShows?.length || 0
          });
        }
        return null;
      })()}

      {/* Selection Modal for multiple results */}
      {/* CRITICAL FIX - Make the modal less restrictive in its rendering conditions */}
      {showSelectionModal && multipleResults && (
        <MediaSelectionModal
          isOpen={true}
          onClose={() => {
            setShowSelectionModal(false);
            setMultipleResults(null);
          }}
          movies={multipleResults.movies}
          tvShows={multipleResults.tvShows}
          onSelectMedia={(media) => {
            try {
              // Ensure we have a valid ID from either source
              const mediaId = media.tmdbId || media.id;
              console.log("Processing media selection:", { mediaId, media });

              if (!mediaId) {
                console.error("Media object missing ID:", media);
                throw new Error("Invalid media selection: Missing ID");
              }

              // Clear the search input and navigate to the appropriate detail page
              setSearchQuery('');

              if ('title' in media) {
                setShowSelectionModal(false);
                setMultipleResults(null);
                navigateWithHistory(`/movie/${mediaId}`);
              } else {
                setShowSelectionModal(false);
                setMultipleResults(null);
                navigateWithHistory(`/tv/${mediaId}`);
              }
            } catch (error) {
              console.error("Error processing media selection:", error);
              toast({
                title: "Navigation Error",
                description: `Could not navigate to detail page: ${error instanceof Error ? error.message : 'Unknown error'}`,
                variant: "destructive"
              });
              setShowSelectionModal(false);
              setMultipleResults(null);
            }
          }}
        />
      )}
    </section>
  );
}